==> jc-1.4.0.tar.gz: java/sql/Types.h <==
// public class java.sql.Types

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fecd3dea3f0b1f32 java_sql_Types

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_sql_Types_H_
#define _JC_java_sql_Types_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_sql_Types$sub_refs	_jc_java_sql_Types$sub_refs;
typedef struct _jc_java_sql_Types$sub_nonrefs	_jc_java_sql_Types$sub_nonrefs;
typedef struct _jc_java_sql_Types$refs	_jc_java_sql_Types$refs;
typedef struct _jc_java_sql_Types$nonrefs	_jc_java_sql_Types$nonrefs;
typedef struct _jc_java_sql_Types$object	_jc_java_sql_Types$object;

typedef struct _jc_java_sql_Types$fields_struct	_jc_java_sql_Types$fields_struct;
typedef const struct _jc_java_sql_Types$vmethods	_jc_java_sql_Types$vmethods;
typedef const struct _jc_java_sql_Types$vtable	_jc_java_sql_Types$vtable;
typedef const struct _jc_java_sql_Types$vtype	_jc_java_sql_Types$vtype;

// Class fields structure
struct _jc_java_sql_Types$fields_struct {
	jint	ARRAY;
	jint	BIGINT;
	jint	BINARY;
	jint	BIT;
	jint	BLOB;
	jint	BOOLEAN;
	jint	CHAR;
	jint	CLOB;
	jint	DATALINK;
	jint	DATE;
	jint	DECIMAL;
	jint	DISTINCT;
	jint	DOUBLE;
	jint	FLOAT;
	jint	INTEGER;
	jint	JAVA__5fOBJECT;
	jint	LONGVARBINARY;
	jint	LONGVARCHAR;
	jint	NULL;
	jint	NUMERIC;
	jint	OTHER;
	jint	REAL;
	jint	REF;
	jint	SMALLINT;
	jint	STRUCT;
	jint	TIME;
	jint	TIMESTAMP;
	jint	TINYINT;
	jint	VARBINARY;
	jint	VARCHAR;
};
extern _jc_java_sql_Types$fields_struct _jc_java_sql_Types$class_fields;

// Constructors
extern void _jc_java_sql_Types$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_sql_Types$object *);

// Virtual methods structure
struct _jc_java_sql_Types$vmethods {
};

// Vtable
struct _jc_java_sql_Types$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_sql_Types$vmethods	java_sql_Types;
};

// Vtype
struct _jc_java_sql_Types$vtype {
	_jc_type			type;
	_jc_java_sql_Types$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_sql_Types$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_sql_Types$refs {
    _jc_java_sql_Types$sub_refs	java_sql_Types;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_sql_Types$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_sql_Types$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_sql_Types$sub_nonrefs	java_sql_Types;
};

// Object instance structure
struct _jc_java_sql_Types$object {
	_jc_java_sql_Types$refs	refs[0];
	_jc_word		lockword;
	_jc_java_sql_Types$vtype	*vtype;
	_jc_java_sql_Types$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_sql_Types$vtype _jc_java_sql_Types$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_sql_Types, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_sql_Types$class_object;

#endif	/* _JC_java_sql_Types_H_ */

==> jc-1.4.6.tar.gz: java/sql/Types.h <==
// public class java.sql.Types

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fecd3dea3f0b1f32 java_sql_Types

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_sql_Types_H_
#define _JC_java_sql_Types_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_sql_Types$sub_refs	_jc_java_sql_Types$sub_refs;
typedef struct _jc_java_sql_Types$sub_nonrefs	_jc_java_sql_Types$sub_nonrefs;
typedef struct _jc_java_sql_Types$refs	_jc_java_sql_Types$refs;
typedef struct _jc_java_sql_Types$nonrefs	_jc_java_sql_Types$nonrefs;
typedef struct _jc_java_sql_Types$object	_jc_java_sql_Types$object;

typedef struct _jc_java_sql_Types$fields_struct	_jc_java_sql_Types$fields_struct;
typedef const struct _jc_java_sql_Types$vmethods	_jc_java_sql_Types$vmethods;
typedef const struct _jc_java_sql_Types$vtable	_jc_java_sql_Types$vtable;
typedef const struct _jc_java_sql_Types$vtype	_jc_java_sql_Types$vtype;

// Class fields structure
struct _jc_java_sql_Types$fields_struct {
	jint	ARRAY;
	jint	BIGINT;
	jint	BINARY;
	jint	BIT;
	jint	BLOB;
	jint	BOOLEAN;
	jint	CHAR;
	jint	CLOB;
	jint	DATALINK;
	jint	DATE;
	jint	DECIMAL;
	jint	DISTINCT;
	jint	DOUBLE;
	jint	FLOAT;
	jint	INTEGER;
	jint	JAVA__5fOBJECT;
	jint	LONGVARBINARY;
	jint	LONGVARCHAR;
	jint	NULL;
	jint	NUMERIC;
	jint	OTHER;
	jint	REAL;
	jint	REF;
	jint	SMALLINT;
	jint	STRUCT;
	jint	TIME;
	jint	TIMESTAMP;
	jint	TINYINT;
	jint	VARBINARY;
	jint	VARCHAR;
};
extern _jc_java_sql_Types$fields_struct _jc_java_sql_Types$class_fields;

// Constructors
extern void _jc_java_sql_Types$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_sql_Types$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_sql_Types$vmethods {
};

// Vtable
struct _jc_java_sql_Types$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_sql_Types$vmethods	java_sql_Types;
};

// Vtype
struct _jc_java_sql_Types$vtype {
	_jc_type			type;
	_jc_java_sql_Types$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_sql_Types$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_sql_Types$refs {
    _jc_java_sql_Types$sub_refs	java_sql_Types;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_sql_Types$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_sql_Types$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_sql_Types$sub_nonrefs	java_sql_Types;
};

// Object instance structure
struct _jc_java_sql_Types$object {
	_jc_java_sql_Types$refs	refs[0];
	_jc_word		lockword;
	_jc_java_sql_Types$vtype	*vtype;
	_jc_java_sql_Types$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_sql_Types$vtype _jc_java_sql_Types$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_sql_Types, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_sql_Types$class_object;

#endif	/* _JC_java_sql_Types_H_ */
